@@ -348,8 +348,8 @@ class FacileToolkit2:
             raise AssertionError("Argument is %s, not a list" % type(in_list))
 
     @keyword
-    def error_message_should_be(self, message, error_locator="//span[contains(@class, 'err') or "
-                                                             "contains(@class, 'wrong') and "
+    def error_message_should_be(self, message, error_locator="//span[(contains(@class, 'err') or "
+                                                             "contains(@class, 'wrong')) and "
                                                              "normalize-space(.)]", timeout=None,
                                 case_insensitive=True, match=True):
         """
